@@ -14,7 +14,9 @@ class geom(object):
         self.aes = {}
         for arg in args:
             if isinstance(arg, aes):
-                self.aes.update({k: v for k, v in arg.items() if k in self.VALID_AES})
+                for k, v in arg.items():
+                    if k in self.VALID_AES:
+                        self.aes[k] = v
             elif isinstance(arg, DataFrame):
                 self.data = arg
             else:
@@ -22,13 +24,20 @@ class geom(object):
         if "data" in kwargs:
             self.data = kwargs.pop("data")
         if "mapping" in kwargs:
-            self.aes.update({k: v for k, v in kwargs.pop("mapping").items() if k in self.VALID_AES})        
+            for k, v in kwargs.pop("mapping").items():
+                if k in self.VALID_AES:
+                    self.aes[k] = v
         if "colour" in kwargs:
             kwargs["color"] = kwargs["colour"]
             del kwargs["colour"]
-        self.manual_aes = {k: v for k, v in kwargs.items() if k in self.VALID_AES}
+
+        self.manual_aes = {}
+        for k, v in kwargs.items():
+            if k in self.VALID_AES:
+                self.manual_aes[k] = v
 
     def __radd__(self, gg):
         gg = deepcopy(gg)
         gg.geoms.append(self)
         return gg
+
