@@ -7,11 +7,12 @@ from pandas.lib import Timestamp
 
 
 class geom_bar(geom):
-    VALID_AES = ['x', 'color', 'alpha', 'fill', 'label', 'weight']
+    VALID_AES = ['x', 'color', 'alpha', 'fill', 'label', 'weight', 'position']
 
     def plot_layer(self, layer):
         layer = {k: v for k, v in layer.items() if k in self.VALID_AES}
         layer.update(self.manual_aes)
+
         x = layer.pop('x')
         if 'weight' not in layer:
             counts = pd.value_counts(x)
@@ -30,12 +31,25 @@ class geom_bar(geom):
                 ts = ts.fillna(0)
                 weights = ts.values.tolist()
                 labels = ts.index.to_pydatetime().tolist()
+
         indentation = np.arange(len(labels)) + 0.2
-        width = 0.35
+        width = 0.9
         idx = np.argsort(labels)
         labels, weights = np.array(labels)[idx], np.array(weights)[idx]
         labels = sorted(labels)
 
+        if 'color' in layer:
+            layer['edgecolor'] = layer['color']
+            del layer['color']
+        else:
+            layer['edgecolor'] = '#333333'
+
+        if 'fill' in layer:
+            layer['color'] = layer['fill']
+            del layer['fill']
+        else:
+            layer['color'] = '#333333'
+
         plt.bar(indentation, weights, width, **layer)
         plt.autoscale()
         return [
