@@ -1,11 +1,11 @@
 import matplotlib.pyplot as plt
 from copy import deepcopy
-from geom import geom
+from .geom import geom
 
 class geom_hline(geom):
-    VALID_AES = ['y', 'xmin', 'xmax', 'color', 'alpha', 'label']
+    VALID_AES = ['y', 'xmin', 'xmax', 'color', 'linestyle', 'alpha', 'label']
     def plot_layer(self, layer):
-        layer = {k: v for k, v in layer.iteritems() if k in self.VALID_AES}
+        layer = {k: v for k, v in layer.items() if k in self.VALID_AES}
         layer.update(self.manual_aes)
         if 'y' in layer:
             y = layer.pop('y')
@@ -27,4 +27,4 @@ class geom_hline(geom):
         else:
             plt.axhline(y=y, **layer)
 
-        
+
