@@ -7,9 +7,9 @@ class scale(object):
             setattr(self, s, None)
 
         if args:
-            self.label = args[0]
+            self.name = args[0]
 
-        for k, v in kwargs.iteritems():
+        for k, v in kwargs.items():
             if k in self.VALID_SCALES:
                 setattr(self, k, v)
 
