@@ -1,21 +1,20 @@
-from scale import scale
+from .scale import scale
 from copy import deepcopy
 import matplotlib.pyplot as plt
 from matplotlib.colors import LinearSegmentedColormap, rgb2hex, ColorConverter
-import numpy as np
 
 
 def colors_at_breaks(cmap, breaks=[0, 0.25, 0.5, 0.75, 1.]):
-        return [rgb2hex(cmap(bb)[:3]) for bb in breaks]
+    return [rgb2hex(cmap(bb)[:3]) for bb in breaks]
 
 
 class scale_colour_gradient(scale):
-    VALID_SCALES = ['label', 'limits', 'low', 'mid', 'high']
-    
+    VALID_SCALES = ['name', 'limits', 'low', 'mid', 'high']
+
     def __radd__(self, gg):
         gg = deepcopy(gg)
-        if self.label:
-            gg.color_label = self.label
+        if self.name:
+            gg.color_label = self.name
         if self.limits:
             gg.color_limits = self.limits
         color_spectrum = []
