@@ -2,7 +2,7 @@ from .utils import ggsave
 from .date_breaks import date_breaks
 from .date_format import date_format
 
-__ALL__ = ["ggsave", "date_breaks", "date_format"]
+__ALL__ = ["ggsave", "date_breaks", "date_format", "add_ggplotrc_params"]
 
 class _rc_context(object):
     def __init__(self, fname=None):
@@ -14,4 +14,4 @@ class _rc_context(object):
             mpl.rcfile(self.fname)
     def __exit__(self, type, value, tb):
         import matplotlib as mpl
-        mpl.rcParams.update(self._rcparams)
\ No newline at end of file
+        mpl.rcParams.update(self._rcparams)
